package net.knarcraft.blacksmith.config;

import org.jetbrains.annotations.NotNull;

/**
 * An interface describing a global setting
 */
public interface GlobalSetting {

    /**
     * Gets the full config path for this setting
     *
     * @return <p>The full config path for this setting</p>
     */
    @NotNull String getPath();

    /**
     * Gets the parent item of the defined path
     *
     * @return <p>The parent node</p>
     */
    @NotNull String getParent();

    /**
     * Gets the value of this setting
     *
     * @return <p>The value of this setting</p>
     */
    @NotNull Object getDefaultValue();

    /**
     * The name of the command used to change this setting
     *
     * @return <p>The name of this setting's command</p>
     */
    @NotNull String getCommandName();

    /**
     * Gets the value type for this setting
     *
     * @return <p>The value type for this setting</p>
     */
    @NotNull SettingValueType getValueType();

}
