package net.knarcraft.blacksmith.config.scrapper;

import net.knarcraft.blacksmith.config.GlobalSetting;
import net.knarcraft.blacksmith.config.SettingValueType;
import org.jetbrains.annotations.NotNull;

import java.util.Arrays;

/**
 * Settings which are the same for every scrapper
 */
public enum GlobalScrapperSetting implements GlobalSetting {

    /**
     * Whether to display exact time in minutes and seconds when displaying a remaining cool-down
     */
    SHOW_EXACT_TIME("scrapper.global.showExactTime", SettingValueType.BOOLEAN, "false",
            "showExactTime"),

    /**
     * Whether to give experience back when salvaging an enchanted item
     */
    GIVE_EXPERIENCE("scrapper.global.giveExperience", SettingValueType.BOOLEAN, "true",
            "giveExperience"),
    ;

    private final String path;
    private final String parent;
    private final String commandName;
    private final Object value;
    private final SettingValueType valueType;

    /**
     * Instantiates a new setting
     *
     * @param path        <p>The full config path for this setting</p>
     * @param valueType   <p>The type of value used by this setting</p>
     * @param value       <p>The default value of this setting</p>
     * @param commandName <p>The name of the command used to change this setting</p>
     */
    GlobalScrapperSetting(String path, SettingValueType valueType, Object value, String commandName) {
        this.path = path;
        this.value = value;
        this.commandName = commandName;
        this.valueType = valueType;
        String[] pathParts = path.split("\\.");
        this.parent = String.join(".", Arrays.copyOfRange(pathParts, 0, pathParts.length - 1));
    }

    @Override
    public @NotNull String getPath() {
        return path;
    }

    @Override
    public @NotNull String getParent() {
        return parent;
    }

    @Override
    public @NotNull Object getDefaultValue() {
        return value;
    }

    @Override
    public @NotNull String getCommandName() {
        return commandName;
    }

    @Override
    public @NotNull SettingValueType getValueType() {
        return this.valueType;
    }

}
