package net.knarcraft.blacksmith.trait;

import net.citizensnpcs.api.util.DataKey;
import net.knarcraft.blacksmith.BlacksmithPlugin;
import net.knarcraft.blacksmith.config.scrapper.ScrapperNPCSettings;
import org.apache.commons.lang.NotImplementedException;
import org.bukkit.Bukkit;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;

/**
 * The class representing a scrapper NPC trait
 */
public class ScrapperTrait extends CustomTrait {

    //TODO: A scrapper will take items and turn them into the base ingredients
    //TODO: If an item is enchanted, give an appropriate amount of exp
    private final ScrapperNPCSettings config;

    /**
     * Instantiates a new blacksmith trait
     */
    public ScrapperTrait() {
        super("scrapper");
        //This should crash if the blacksmith plugin hasn't been properly registered
        Bukkit.getServer().getPluginManager().getPlugin("Blacksmith");
        this.config = new ScrapperNPCSettings(BlacksmithPlugin.getInstance().getGlobalScrapperSettings());
        super.setTraitSettings(this.config);
    }

    /**
     * Gets the current settings for this NPC
     *
     * @return <p>The current settings for this NPC</p>
     */
    public ScrapperNPCSettings getSettings() {
        return config;
    }

    /**
     * Loads all config values stored in citizens' config file for this NPC
     *
     * @param key <p>The data key used for the config root</p>
     */
    @Override
    public void load(@NotNull DataKey key) {
        config.loadVariables(key);
    }

    /**
     * Saves all config values for this NPC
     *
     * @param key <p>The data key used for the config root</p>
     */
    @Override
    public void save(@NotNull DataKey key) {
        config.saveVariables(key);
    }

    /**
     * Starts a new session, and prepares to repair the player's item
     *
     * @param player <p>The player to start the session for</p>
     */
    public void startSession(@NotNull Player player) {
        // TODO: Need some method to check which items are salvageable by the specific NPC. It should be similar to 
        //  reforge-able items. Optionally, extended mode can be enabled, which supports any recipe?
        // TODO: Check if the held item is salvageable, and give appropriate messages
        // TODO: Mark the session start
        // TODO: Initialize a new session
        // TODO: Tell player about the required cost
        throw new NotImplementedException();
    }

    @Override
    protected boolean showExactTime() {
        return BlacksmithPlugin.getInstance().getGlobalScrapperSettings().getShowExactTime();
    }

}
